package utils

const (
	minUsername        = "2"
	maxUsername        = "20"
	MinUsername        = 2
	MaxUsername        = 20
	minPassword        = "6"
	MinPassword        = 6
	maxPassword        = "64"
	MaxPassword        = 64
	minScannerName     = "3"
	maxScannerName     = "16"
	MinRoleDisplayName = 3
	MaxRoleDisplayName = 30
	MaxRoleDescription = 80

	LenHeaderXAuthorization = 36
	lenHeaderXAuthorization = "36"
	LenUserId               = 36

	HeaderXAuthorization = "X-Authorization"

	MaxAvatarSize = 5 * 1024 * 1024 // 5 MB

	GroupTaskLockedTime  = 3
	SessionExpiresAtTime = 7 * 24 * 60 * 60 // 1 week

	ConnectionStateOffline = 0
	ConnectionStateOnline  = 1
)

// commands sent to web clients
const (
	SentCmdInitUserSocketConnection        = 1
	SentCmdUpdateConnectedUsers            = 2
	SentCmdNewGroupTaskStarted             = 3
	SentCmdNewGroupTaskStep                = 4
	SentCmdUpdateGroupTaskStep             = 5
	SentCmdUpdateGroupTask                 = 6
	SentCmdReloadingGroupTasks             = 7
	SentCmdGroupTasksReloaded              = 8
	SentCmdUpdateUserSessions              = 9
	SentCmdUpdateAllUsersUserAvatar        = 10
	SentCmdNewScanner                      = 11
	SentCmdDeleteScanner                   = 12
	SentCmdUpdateScannerUsedBy             = 13
	SentCmdScanResult                      = 14
	SentCmdUpdateScannerLastUsed           = 15
	SentCmdTaskLocked                      = 16
	SentCmdTaskUnlocked                    = 17
	SentCmdUserProfileUpdated              = 18
	SentCmdAdminAreaNewRoleCreated         = 19
	SentCmdAdminAreaRoleUpdated            = 20
	SentCmdAdminAreaUpdateRoleSortingOrder = 21
	SentCmdAdminAreaRoleDeleted            = 22
	SentCmdAllUsersUserRoleUpdated         = 23
	SentCmdRolePermissionsUpdated          = 24
	SentCmdErrorNoPermissions              = 25
	SentCmdAllUsersNewUserCreated          = 26
	SentCmdAllUsersUserDeleted             = 27
)

// commands received from web clients
const (
	ReceivedCmdStartGroupTasks                 = 1
	ReceivedCmdTaskFailedTryAgainRunTaskStep   = 2
	ReceivedCmdTaskContinueTaskStep            = 3
	ReceivedCmdReloadGroupTasks                = 4
	ReceivedCmdTaskLocking                     = 5
	ReceivedCmdUpdateUserProfile               = 6
	ReceivedCmdAdminAreaCreateNewRole          = 7
	ReceivedCmdAdminAreaUpdateRole             = 8
	ReceivedCmdAdminAreaUpdateRoleSortingOrder = 9
	ReceivedCmdAdminAreaDeleteRole             = 10
	ReceivedCmdAllUsersUpdateUserRole          = 11
	ReceivedCmdAllUsersCreateNewUser           = 12
	ReceivedCmdAllUsersDeleteUser              = 13
)

const (
	GroupTasksStatusFinished      uint8 = 1
	GroupTasksStatusRunning       uint8 = 2
	GroupTasksStatusCanceled      uint8 = 3
	GroupTasksStatusFailed        uint8 = 4
	GroupTasksStatusInputRequired uint8 = 5
)

var (
	generalRules = map[string]string{
		"Username":    "required,min=" + minUsername + ",max=" + maxUsername,
		"Password":    "required", // length is checked later because sent in base64
		"SessionId":   "required,len=" + lenHeaderXAuthorization,
		"ScannerName": "required,min=" + minScannerName + ",max=" + maxScannerName,
	}
)

const (
	_groupTasks                                     = "group_tasks."
	PermissionGroupTasksOverviewXYNewTask           = _groupTasks + "overview.XY.new_task"
	PermissionGroupTasksOverviewXYReloadGroupConfig = _groupTasks + "overview.XY.reload_group_config"
	PermissionGroupTasksOverviewXYView              = _groupTasks + "overview.XY.view"
	PermissionGroupTasksHistory                     = _groupTasks + "history"

	PermissionAllUsersCreateNewUser    = "all_users.create_new_user"
	PermissionAllUsersActionChangeRole = "all_users.action.change_role"
	PermissionAllUsersActionDeleteUser = "all_users.action.delete_user"
	PermissionScannerUseScanners       = "scanner.use_scanners"

	_adminArea                        = "admin_area."
	_adminAreaRoles                   = _adminArea + "roles."
	PermissionAdminAreaCreateNewRole  = _adminAreaRoles + "create_new_role"
	PermissionAdminAreaUpdateRole     = _adminAreaRoles + "update_role"
	PermissionAdminAreaDeleteRole     = _adminAreaRoles + "delete_role"
	PermissionAdminAreaMoveRoleUpDown = _adminAreaRoles + "move_role_up_down"
	PermissionAdminAreaLogs           = _adminArea + "logs"
)
